@@ -25,7 +25,7 @@ mbrier = function(truth, prob, ...) {
 
   mat01 = contr.treatment(colnames(prob), contrasts = FALSE)
   mat01 = mat01[match(truth, rownames(mat01)), ]
-  mean(rowSums(se(mat01, prob)))
+  mean(rowSums(.se(mat01, prob)))
 }
 
 #' @include measures.R
