@@ -15,8 +15,8 @@
 #' @export
 mse = function(truth, response, sample_weights = NULL, ...) {
   assert_regr(truth, response = response)
-  wmean(se(truth, response), sample_weights)
+  wmean(.se(truth, response), sample_weights)
 }
 
 #' @include measures.R
-add_measure(mse, "Mean Squared Error", "regr", 0, Inf, TRUE)
+add_measure(mse, "Mean Squared Error", "regr", 0, Inf, TRUE, obs_loss = "se")
