@@ -23,7 +23,7 @@ rrse = function(truth, response, na_value = NaN, ...) {
   if (v < TOL) {
     return(na_value)
   }
-  sqrt(sum(se(truth, response)) / (v * (length(truth) - 1L)))
+  sqrt(sum(.se(truth, response)) / (v * (length(truth) - 1L)))
 }
 
 #' @include measures.R
